@@ -16,7 +16,7 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: recipes.c 2146 2006-05-23 17:36:00Z xavier $
+ $Id: signals.c 13799 2015-04-08 22:44:31Z dstrubbe $
 */
 
 #include <config.h>
@@ -27,7 +27,7 @@
 
 
 void FC_FUNC_(block_signals, BLOCK_SIGNALS)(){
-#if HAVE_SIGACTION && HAVE_SIGNAL_H
+#if defined(HAVE_SIGACTION) && defined(HAVE_SIGNAL_H)
   struct sigaction act;
 
   act.sa_handler = SIG_IGN;
@@ -40,7 +40,7 @@ void FC_FUNC_(block_signals, BLOCK_SIGNALS)(){
 }
 
 void FC_FUNC_(unblock_signals, UNBLOCK_SIGNALS)(){
-#if HAVE_SIGACTION && HAVE_SIGNAL_H
+#if defined(HAVE_SIGACTION) && defined(HAVE_SIGNAL_H)
   struct sigaction act;
 
   act.sa_handler = SIG_DFL;
