@@ -15,7 +15,7 @@
 !! Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 !! 02110-1301, USA.
 !!
-!! $Id: global.h 12142 2014-05-27 09:38:41Z micael $
+!! $Id: global.h 15024 2016-01-09 16:46:25Z xavier $
 
 #include "config_F90.h"
 
@@ -188,11 +188,11 @@
 ! in the messages_m module.
 #define PUSH_SUB(routine) \
   if(in_debug_mode) then; _newline_ \
-    call push_sub(__FILE__//"." _anl_ //TOSTRING(routine)); _newline_ \
+    call push_sub(__FILE__+"." _anl_ +TOSTRING(routine)); _newline_ \
   endif
 #define POP_SUB(routine) \
   if(in_debug_mode) then; _newline_ \
-    call pop_sub(__FILE__//"." _anl_ //TOSTRING(routine)); _newline_ \
+    call pop_sub(__FILE__+"." _anl_ +TOSTRING(routine)); _newline_ \
   endif
 
 ! the leading dimension of the array
