@@ -114,7 +114,7 @@ static SYMMETRY_ELEMENT **    ImproperAxes          = NULL ;
 static int *                  NormalAxesCounts      = NULL ;
 static int *                  ImproperAxesCounts    = NULL ;
 static int                    BadOptimization       = 0 ;
-static char *                 SymmetryCode          = "" ;
+static char *                 SymmetryCode          = NULL; /*"" ;*/
 /*
  *    Statistics
  */
@@ -381,7 +381,7 @@ if( elem->nparam >= 4 ){
         }
     r = sqrt( r ) ;
     if( r < ToleranceSame ){
-        fprintf( stderr, "Normal collapced!\n" ) ;
+        fprintf( stderr, "Normal collapsed!\n" ) ;
         exit( EXIT_FAILURE ) ;
         }
     for( k = 0 ; k < DIMENSION ; k++ ){
@@ -400,7 +400,7 @@ if( elem->nparam >= 7 ){
         }
     r = sqrt( r ) ;
     if( r < ToleranceSame ){
-        fprintf( stderr, "Direction collapced!\n" ) ;
+        fprintf( stderr, "Direction collapsed!\n" ) ;
         exit( EXIT_FAILURE ) ;
         }
     for( k = 0 ; k < DIMENSION ; k++ ){
@@ -1049,14 +1049,19 @@ axis->direction[2] = (b[0]-a[0])*(c[1]-b[1]) - (b[1]-a[1])*(c[0]-b[0]) ;
  *  of the direction is positive.
  */
 sign = 0 ;
-if( axis->direction[0] <= 0 )
-    if( axis->direction[0] < 0 )
-         sign = 1 ;
-    else if( axis->direction[1] <= 0 )
-             if( axis->direction[1] < 0 )
+if( axis->direction[0] <= 0 ) {
+    if( axis->direction[0] < 0 ) {
+        sign = 1 ;
+    }
+    else if( axis->direction[1] <= 0 ) {
+             if( axis->direction[1] < 0 ) {
+                 sign = 1 ;
+         }
+         else if( axis->direction[2] < 0 ) {
                   sign = 1 ;
-             else if( axis->direction[2] < 0 )
-                      sign = 1 ;
+         }
+    }
+}
 if( sign )
     for( i = 0 ; i < DIMENSION ; i++ )
         axis->direction[i] = -axis->direction[i] ;
@@ -1223,7 +1228,7 @@ void
 find_planes(void)
 {
         int                i, j ;
-        SYMMETRY_ELEMENT * plane ;
+        SYMMETRY_ELEMENT * plane=NULL;
 
 plane = init_ultimate_plane() ;
 if( plane != NULL ){
@@ -1260,6 +1265,7 @@ destroy_planes(void)
   for(i = 0; i < PlanesCount; i++) destroy_symmetry_element(Planes[i]);
   PlanesCount = 0;
   free(Planes);
+  MolecularPlane = NULL;
   Planes = NULL;
 }
 
@@ -1769,9 +1775,9 @@ void FC_FUNC_(symmetries_finite_get_group_name,SYMMETRIES_FINITE_GET_GROUP_NAME)
 }
 
 void FC_FUNC_(symmetries_finite_get_group_elements,SYMMETRIES_FINITE_GET_GROUP_ELEMENTS)
-     (const int * point_group,  STR_F_TYPE name STR_ARG1){
+     (const int * point_group,  STR_F_TYPE elements STR_ARG1){
 
-  TO_F_STR1(PointGroups[*point_group].symmetry_code, name);
+  TO_F_STR1(PointGroups[*point_group].symmetry_code, elements);
 }
 
 void FC_FUNC_(symmetries_finite_end,SYMMETRIES_FINITE_END)(){  
