@@ -17,7 +17,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 #
-# $Id: oct-run_regression_test.pl 14029 2015-05-18 18:22:34Z dstrubbe $
+# $Id: oct-run_regression_test.pl 14747 2015-11-07 20:39:10Z dstrubbe $
 
 use warnings;
 use Getopt::Std;
@@ -629,6 +629,6 @@ sub die255 {
 }
 
 sub skip_exit {
-    print "Status: skipped\n";
+    print "Status: skipped\n\n";
     exit 254;  
 }
